==> apache-iotdb-1.3.3-source-release.zip: apache-iotdb-1.3.3/iotdb-client/service-rpc/src/main/java/org/apache/iotdb/rpc/subscription/exception/SubscriptionPipeTimeoutException.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package org.apache.iotdb.rpc.subscription.exception;

import java.util.Objects;

public class SubscriptionPipeTimeoutException extends SubscriptionRuntimeNonCriticalException {

  public SubscriptionPipeTimeoutException(final String message) {
    super(message);
  }

  public SubscriptionPipeTimeoutException(final String message, final Throwable cause) {
    super(message, cause);
  }

  @Override
  public boolean equals(final Object obj) {
    return obj instanceof SubscriptionPipeTimeoutException
        && Objects.equals(getMessage(), ((SubscriptionPipeTimeoutException) obj).getMessage())
        && Objects.equals(getTimeStamp(), ((SubscriptionPipeTimeoutException) obj).getTimeStamp());
  }

  @Override
  public int hashCode() {
    return super.hashCode();
  }
}

==> apache-iotdb-1.3.6-source-release.zip: apache-iotdb-1.3.6/iotdb-client/service-rpc/src/main/java/org/apache/iotdb/rpc/subscription/exception/SubscriptionPipeTimeoutException.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package org.apache.iotdb.rpc.subscription.exception;

import java.util.Objects;

public class SubscriptionPipeTimeoutException extends SubscriptionTimeoutException {

  public SubscriptionPipeTimeoutException(final String message) {
    super(message);
  }

  public SubscriptionPipeTimeoutException(final String message, final Throwable cause) {
    super(message, cause);
  }

  @Override
  public boolean equals(final Object obj) {
    return obj instanceof SubscriptionPipeTimeoutException
        && Objects.equals(getMessage(), ((SubscriptionPipeTimeoutException) obj).getMessage())
        && Objects.equals(getTimeStamp(), ((SubscriptionPipeTimeoutException) obj).getTimeStamp());
  }

  @Override
  public int hashCode() {
    return super.hashCode();
  }
}
